=======================
Tutorials Home
=======================

Aydin tutorials give an in-depth description of all the available features and parameters for
the three main user interfaces it provides:


#. `Aydin Studio -- the user-friendly graphical user interface  (GUI) <gui_tutorials.html>`_
#. `Command Line Interface (CLI) for headless operation <cli_tutorials.html>`_
#. `Application Programming Interface (API) for Python scripting and integration <api_tutorials.html>`_
